import * as React from 'react';
import { View, ViewStyle, StyleProp } from 'react-native';
import type { Theme } from '../../types';
declare type Props = Partial<React.ComponentPropsWithRef<typeof View>> & {
    /**
     * Whether the background color is a dark color. A dark appbar will render light text and vice-versa.
     */
    dark?: boolean;
    /**
     * Content of the `Appbar`.
     */
    children: React.ReactNode;
    /**
     * @supported Available in v5.x with theme version 3
     *
     * Mode of the Appbar.
     * - `small` - Appbar with default height (64).
     * - `medium` - Appbar with medium height (112).
     * - `large` - Appbar with large height (152).
     * - `center-aligned` - Appbar with default height and center-aligned title.
     */
    mode?: 'small' | 'medium' | 'large' | 'center-aligned';
    /**
     * @supported Available in v5.x with theme version 3
     * Whether Appbar background should have the elevation along with primary color pigment.
     */
    elevated?: boolean;
    /**
     * @optional
     */
    theme: Theme;
    style?: StyleProp<ViewStyle>;
};
declare const _default: React.ComponentType<Pick<Partial<import("react-native").ViewProps & React.RefAttributes<View>> & {
    /**
     * Whether the background color is a dark color. A dark appbar will render light text and vice-versa.
     */
    dark?: boolean | undefined;
    /**
     * Content of the `Appbar`.
     */
    children: React.ReactNode;
    /**
     * @supported Available in v5.x with theme version 3
     *
     * Mode of the Appbar.
     * - `small` - Appbar with default height (64).
     * - `medium` - Appbar with medium height (112).
     * - `large` - Appbar with large height (152).
     * - `center-aligned` - Appbar with default height and center-aligned title.
     */
    mode?: "small" | "medium" | "large" | "center-aligned" | undefined;
    /**
     * @supported Available in v5.x with theme version 3
     * Whether Appbar background should have the elevation along with primary color pigment.
     */
    elevated?: boolean | undefined;
    /**
     * @optional
     */
    theme: Theme;
    style?: StyleProp<ViewStyle>;
}, "dark" | keyof import("react-native").ViewProps | "mode" | keyof React.RefAttributes<View> | "elevated"> & {
    theme?: import("@callstack/react-theme-provider").$DeepPartial<Theme> | undefined;
}> & import("@callstack/react-theme-provider/typings/hoist-non-react-statics").NonReactStatics<React.ComponentType<Partial<import("react-native").ViewProps & React.RefAttributes<View>> & {
    /**
     * Whether the background color is a dark color. A dark appbar will render light text and vice-versa.
     */
    dark?: boolean | undefined;
    /**
     * Content of the `Appbar`.
     */
    children: React.ReactNode;
    /**
     * @supported Available in v5.x with theme version 3
     *
     * Mode of the Appbar.
     * - `small` - Appbar with default height (64).
     * - `medium` - Appbar with medium height (112).
     * - `large` - Appbar with large height (152).
     * - `center-aligned` - Appbar with default height and center-aligned title.
     */
    mode?: "small" | "medium" | "large" | "center-aligned" | undefined;
    /**
     * @supported Available in v5.x with theme version 3
     * Whether Appbar background should have the elevation along with primary color pigment.
     */
    elevated?: boolean | undefined;
    /**
     * @optional
     */
    theme: Theme;
    style?: StyleProp<ViewStyle>;
}> & (({ children, dark, style, theme, mode, elevated, ...rest }: Props) => JSX.Element), {}>;
export default _default;
declare const AppbarWithTheme: React.ComponentType<Pick<Partial<import("react-native").ViewProps & React.RefAttributes<View>> & {
    /**
     * Whether the background color is a dark color. A dark appbar will render light text and vice-versa.
     */
    dark?: boolean | undefined;
    /**
     * Content of the `Appbar`.
     */
    children: React.ReactNode;
    /**
     * @supported Available in v5.x with theme version 3
     *
     * Mode of the Appbar.
     * - `small` - Appbar with default height (64).
     * - `medium` - Appbar with medium height (112).
     * - `large` - Appbar with large height (152).
     * - `center-aligned` - Appbar with default height and center-aligned title.
     */
    mode?: "small" | "medium" | "large" | "center-aligned" | undefined;
    /**
     * @supported Available in v5.x with theme version 3
     * Whether Appbar background should have the elevation along with primary color pigment.
     */
    elevated?: boolean | undefined;
    /**
     * @optional
     */
    theme: Theme;
    style?: StyleProp<ViewStyle>;
}, "dark" | keyof import("react-native").ViewProps | "mode" | keyof React.RefAttributes<View> | "elevated"> & {
    theme?: import("@callstack/react-theme-provider").$DeepPartial<Theme> | undefined;
}> & import("@callstack/react-theme-provider/typings/hoist-non-react-statics").NonReactStatics<React.ComponentType<Partial<import("react-native").ViewProps & React.RefAttributes<View>> & {
    /**
     * Whether the background color is a dark color. A dark appbar will render light text and vice-versa.
     */
    dark?: boolean | undefined;
    /**
     * Content of the `Appbar`.
     */
    children: React.ReactNode;
    /**
     * @supported Available in v5.x with theme version 3
     *
     * Mode of the Appbar.
     * - `small` - Appbar with default height (64).
     * - `medium` - Appbar with medium height (112).
     * - `large` - Appbar with large height (152).
     * - `center-aligned` - Appbar with default height and center-aligned title.
     */
    mode?: "small" | "medium" | "large" | "center-aligned" | undefined;
    /**
     * @supported Available in v5.x with theme version 3
     * Whether Appbar background should have the elevation along with primary color pigment.
     */
    elevated?: boolean | undefined;
    /**
     * @optional
     */
    theme: Theme;
    style?: StyleProp<ViewStyle>;
}> & (({ children, dark, style, theme, mode, elevated, ...rest }: Props) => JSX.Element), {}>;
export { AppbarWithTheme as Appbar };
